==> boutdata-0.1.2.tar.gz: boutdata-0.1.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
import setuptools
from pathlib import Path

name = 'boutdata'
root_path = Path(__file__).parent
init_path = root_path.joinpath(name, '__init__.py')
readme_path = root_path.joinpath('README.md')

# https://packaging.python.org/guides/single-sourcing-package-version/
with init_path.open('r') as f:
    version_file = f.read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        version = version_match.group(1)
    else:
        raise RuntimeError('Unable to find version string.')

with readme_path.open('r') as f:
    long_description = f.read()

setuptools.setup(
    name=name,
    version=version,
    author='Ben Dudson et al.',
    description='Python package for collecting BOUT++ data',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='http://boutproject.github.io',
    project_urls={
        "Bug Tracker": "https://github.com/boutproject/boutdata/issues/",
        "Documentation": "http://bout-dev.readthedocs.io/en/latest/",
        "Source Code": "https://github.com/boutproject/boutdata/",
    },
    packages=setuptools.find_packages(),
    keywords=['bout++',
              'bout',
              'plasma',
              'physics',
              'data-extraction',
              'data-analysis',
              'data-visualization'],
    install_requires=['sympy',
                      'numpy',
                      'matplotlib',
                      'scipy',
                      'bunch',
                      'boututils'],
    classifiers=[
        'Programming Language :: Python :: 3',
        ('License :: OSI Approved :: '
         'GNU Lesser General Public License v3 or later (LGPLv3+)'),
        'Operating System :: OS Independent',
    ],
)

==> boutdata-0.1.3.tar.gz: boutdata-0.1.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
import setuptools
from pathlib import Path

name = 'boutdata'
root_path = Path(__file__).parent
init_path = root_path.joinpath(name, '__init__.py')
readme_path = root_path.joinpath('README.md')

with readme_path.open('r') as f:
    long_description = f.read()

setuptools.setup(
    name=name,
    author='Ben Dudson et al.',
    description='Python package for collecting BOUT++ data',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/boutproject/boutdata',
    project_urls={
        "Bug Tracker": "https://github.com/boutproject/boutdata/issues/",
        "Documentation": "https://bout-dev.readthedocs.io/en/latest/",
        "Source Code": "https://github.com/boutproject/boutdata/",
    },
    packages=setuptools.find_packages(),
    keywords=['bout++',
              'bout',
              'plasma',
              'physics',
              'data-extraction',
              'data-analysis',
              'data-visualization'],
    use_scm_version=True,
    setup_requires=['setuptools>=42',
                    'setuptools_scm[toml]>=3.4',
                    'setuptools_scm_git_archive'],
    install_requires=['sympy',
                      'numpy',
                      'matplotlib',
                      'scipy',
                      'boututils',
                      "importlib-metadata ; python_version<'3.8'"],
    classifiers=[
        'Programming Language :: Python :: 3',
        ('License :: OSI Approved :: '
         'GNU Lesser General Public License v3 or later (LGPLv3+)'),
        'Operating System :: OS Independent',
    ],
)
